<?php

$lista_nazioni = array();
$cod_nazioni = array();
$cod2_nazioni = array();
$cod3_nazioni = array();

$lista_nazioni[0] = "Austria";
$cod_nazioni[0] = "AT";
$cod2_nazioni[0] = "AUT";
$lista_nazioni[1] = "Bélgica";
$cod_nazioni[1] = "BE";
$cod2_nazioni[1] = "BEL";
$lista_nazioni[2] = "República Checa";
$cod_nazioni[2] = "CZ";
$cod2_nazioni[2] = "CZE";
$lista_nazioni[3] = "Chipre";
$cod_nazioni[3] = "CY";
$cod2_nazioni[3] = "CYP";
$lista_nazioni[4] = "Dinamarca";
$cod_nazioni[4] = "DK";
$cod2_nazioni[4] = "DNK";
$lista_nazioni[5] = "Estonia";
$cod_nazioni[5] = "EE";
$cod2_nazioni[5] = "EST";
$lista_nazioni[6] = "Finlandia";
$cod_nazioni[6] = "FI";
$cod2_nazioni[6] = "FIN";
$lista_nazioni[7] = "Francia";
$cod_nazioni[7] = "FR";
$cod2_nazioni[7] = "FRA";
$lista_nazioni[8] = "Alemania";
$cod_nazioni[8] = "DE";
$cod2_nazioni[8] = "DEU";
$lista_nazioni[9] = "Grecia";
$cod_nazioni[9] = "GR";
$cod2_nazioni[9] = "GRC";
$lista_nazioni[10] = "Irlanda";
$cod_nazioni[10] = "IE";
$cod2_nazioni[10] = "IRL";
$lista_nazioni[11] = "Letonia";
$cod_nazioni[11] = "LV";
$cod2_nazioni[11] = "LVA";
$lista_nazioni[12] = "Lituania";
$cod_nazioni[12] = "LT";
$cod2_nazioni[12] = "LTU";
$lista_nazioni[13] = "Luxemburgo";
$cod_nazioni[13] = "LU";
$cod2_nazioni[13] = "LUX";
$lista_nazioni[14] = "Malta";
$cod_nazioni[14] = "MT";
$cod2_nazioni[14] = "MLT";
$lista_nazioni[15] = "Países Bajos";
$cod_nazioni[15] = "NL";
$cod2_nazioni[15] = "NLD";
$lista_nazioni[16] = "Polonia";
$cod_nazioni[16] = "PL";
$cod2_nazioni[16] = "POL";
$lista_nazioni[17] = "Portugal";
$cod_nazioni[17] = "PT";
$cod2_nazioni[17] = "PRT";
$lista_nazioni[18] = "Reino Unido";
$cod_nazioni[18] = "GB";
$cod2_nazioni[18] = "GBR";
$lista_nazioni[19] = "Eslovaquia";
$cod_nazioni[19] = "SK";
$cod2_nazioni[19] = "SVK";
$lista_nazioni[20] = "Eslovenia";
$cod_nazioni[20] = "SI";
$cod2_nazioni[20] = "SVN";
$lista_nazioni[21] = "España";
$cod_nazioni[21] = "ES";
$cod2_nazioni[21] = "ESP";
$lista_nazioni[22] = "Suecia";
$cod_nazioni[22] = "SE";
$cod2_nazioni[22] = "SWE";
$lista_nazioni[23] = "Hungría";
$cod_nazioni[23] = "HU";
$cod2_nazioni[23] = "HUN";
$lista_nazioni[24] = "Albania";
$cod_nazioni[24] = "AL";
$cod2_nazioni[24] = "ALB";
$lista_nazioni[25] = "Andorra";
$cod_nazioni[25] = "AD";
$cod2_nazioni[25] = "AND";
$lista_nazioni[26] = "Belarús";
$cod_nazioni[26] = "BY";
$cod2_nazioni[26] = "BLR";
$lista_nazioni[27] = "Bosnia Y Herzegovina";
$cod_nazioni[27] = "BA";
$cod2_nazioni[27] = "BIH";
$lista_nazioni[28] = "Bulgaria";
$cod_nazioni[28] = "BG";
$cod2_nazioni[28] = "BGR";
$lista_nazioni[29] = "Croacia";
$cod_nazioni[29] = "HR";
$cod2_nazioni[29] = "HRV";
$lista_nazioni[30] = "Islanda";
$cod_nazioni[30] = "IS";
$cod2_nazioni[30] = "ISL";
$lista_nazioni[31] = "Liechtenstein";
$cod_nazioni[31] = "LI";
$cod2_nazioni[31] = "LIE";
$lista_nazioni[32] = "Macedonia";
$cod_nazioni[32] = "MK";
$cod2_nazioni[32] = "MKD";
$lista_nazioni[33] = "Moldova";
$cod_nazioni[33] = "MD";
$cod2_nazioni[33] = "MDA";
$lista_nazioni[34] = "Mónaco";
$cod_nazioni[34] = "MC";
$cod2_nazioni[34] = "MCO";
$lista_nazioni[35] = "Montenegro";
$cod_nazioni[35] = "ME";
$cod2_nazioni[35] = "MNE";
$lista_nazioni[36] = "Noruega";
$cod_nazioni[36] = "NO";
$cod2_nazioni[36] = "NOR";
$lista_nazioni[37] = "Rumania";
$cod_nazioni[37] = "RO";
$cod2_nazioni[37] = "ROU";
$lista_nazioni[38] = "Rusia";
$cod_nazioni[38] = "RU";
$cod2_nazioni[38] = "RUS";
$lista_nazioni[39] = "San Marino";
$cod_nazioni[39] = "SM";
$cod2_nazioni[39] = "SMR";
$lista_nazioni[40] = "Santa Sede";
$cod_nazioni[40] = "VA";
$cod2_nazioni[40] = "VAT";
$lista_nazioni[41] = "Serbia";
$cod_nazioni[41] = "YU";
$cod2_nazioni[41] = "SRB";
$lista_nazioni[42] = "Suiza";
$cod_nazioni[42] = "CH";
$cod2_nazioni[42] = "CHE";
$lista_nazioni[43] = "Turquía";
$cod_nazioni[43] = "TR";
$cod2_nazioni[43] = "TUR";
$lista_nazioni[44] = "Ucrania";
$cod_nazioni[44] = "UA";
$cod2_nazioni[44] = "UKR";
$lista_nazioni[45] = "Afganistán";
$cod_nazioni[45] = "AF";
$cod2_nazioni[45] = "AFG";
$lista_nazioni[46] = "Arabia Saudita";
$cod_nazioni[46] = "SA";
$cod2_nazioni[46] = "SAU";
$lista_nazioni[47] = "Armenia";
$cod_nazioni[47] = "AM";
$cod2_nazioni[47] = "ARM";
$lista_nazioni[48] = "Azerbaiyán";
$cod_nazioni[48] = "AZ";
$cod2_nazioni[48] = "AZE";
$lista_nazioni[49] = "Bahrein";
$cod_nazioni[49] = "BH";
$cod2_nazioni[49] = "BHR";
$lista_nazioni[50] = "Bangladesh";
$cod_nazioni[50] = "BD";
$cod2_nazioni[50] = "BGD";
$lista_nazioni[51] = "Bhután";
$cod_nazioni[51] = "BT";
$cod2_nazioni[51] = "BTN";
$lista_nazioni[52] = "Brunei";
$cod_nazioni[52] = "BN";
$cod2_nazioni[52] = "BRN";
$lista_nazioni[53] = "Camboya";
$cod_nazioni[53] = "KH";
$cod2_nazioni[53] = "KHM";
$lista_nazioni[54] = "China";
$cod_nazioni[54] = "CN";
$cod2_nazioni[54] = "CHN";
$lista_nazioni[55] = "Corea Del Sur";
$cod_nazioni[55] = "KR";
$cod2_nazioni[55] = "KOR";
$lista_nazioni[56] = "Corea Del Norte";
$cod_nazioni[56] = "KP";
$cod2_nazioni[56] = "PRK";
$lista_nazioni[57] = "Emiratos Arabes Unidos";
$cod_nazioni[57] = "AE";
$cod2_nazioni[57] = "ARE";
$lista_nazioni[58] = "Filipinas";
$cod_nazioni[58] = "PH";
$cod2_nazioni[58] = "PHL";
$lista_nazioni[59] = "Georgia";
$cod_nazioni[59] = "GE";
$cod2_nazioni[59] = "GEO";
$lista_nazioni[60] = "Japón";
$cod_nazioni[60] = "JP";
$cod2_nazioni[60] = "JPN";
$lista_nazioni[61] = "Jordania";
$cod_nazioni[61] = "JO";
$cod2_nazioni[61] = "JOR";
$lista_nazioni[62] = "India";
$cod_nazioni[62] = "IN";
$cod2_nazioni[62] = "IND";
$lista_nazioni[63] = "Indonesia";
$cod_nazioni[63] = "ID";
$cod2_nazioni[63] = "IDN";
$lista_nazioni[64] = "Irán";
$cod_nazioni[64] = "IR";
$cod2_nazioni[64] = "IRN";
$lista_nazioni[65] = "Iraq";
$cod_nazioni[65] = "IQ";
$cod2_nazioni[65] = "IRQ";
$lista_nazioni[66] = "Israel";
$cod_nazioni[66] = "IL";
$cod2_nazioni[66] = "ISR";
$lista_nazioni[67] = "Kazajstán";
$cod_nazioni[67] = "KZ";
$cod2_nazioni[67] = "KAZ";
$lista_nazioni[68] = "Kirguistán";
$cod_nazioni[68] = "KG";
$cod2_nazioni[68] = "KGZ";
$lista_nazioni[69] = "Kuwait";
$cod_nazioni[69] = "KW";
$cod2_nazioni[69] = "KWT";
$lista_nazioni[70] = "Lao";
$cod_nazioni[70] = "LA";
$cod2_nazioni[70] = "LAO";
$lista_nazioni[71] = "Líbano";
$cod_nazioni[71] = "LB";
$cod2_nazioni[71] = "LBN";
$lista_nazioni[72] = "Malasia";
$cod_nazioni[72] = "MY";
$cod2_nazioni[72] = "MYS";
$lista_nazioni[73] = "Maldivas";
$cod_nazioni[73] = "MV";
$cod2_nazioni[73] = "MDV";
$lista_nazioni[74] = "Mongolia";
$cod_nazioni[74] = "MN";
$cod2_nazioni[74] = "MNG";
$lista_nazioni[75] = "Myanmar";
$cod_nazioni[75] = "MM";
$cod2_nazioni[75] = "MMR";
$lista_nazioni[76] = "Nepal";
$cod_nazioni[76] = "NP";
$cod2_nazioni[76] = "NPL";
$lista_nazioni[77] = "Omán";
$cod_nazioni[77] = "OM";
$cod2_nazioni[77] = "OMN";
$lista_nazioni[78] = "Pakistán";
$cod_nazioni[78] = "PK";
$cod2_nazioni[78] = "PAK";
$lista_nazioni[79] = "Qatar";
$cod_nazioni[79] = "QA";
$cod2_nazioni[79] = "QAT";
$lista_nazioni[80] = "Singapur";
$cod_nazioni[80] = "SG";
$cod2_nazioni[80] = "SGP";
$lista_nazioni[81] = "Siria";
$cod_nazioni[81] = "SY";
$cod2_nazioni[81] = "SYR";
$lista_nazioni[82] = "Sri Lanka";
$cod_nazioni[82] = "LK";
$cod2_nazioni[82] = "LKA";
$lista_nazioni[83] = "Tayikistán";
$cod_nazioni[83] = "TJ";
$cod2_nazioni[83] = "TJK";
$lista_nazioni[84] = "Taiwan";
$cod_nazioni[84] = "TW";
$cod2_nazioni[84] = "TWN";
$lista_nazioni[85] = "Palestina";
$cod_nazioni[85] = "PS";
$cod2_nazioni[85] = "PSE";
$lista_nazioni[86] = "Tailandia";
$cod_nazioni[86] = "TH";
$cod2_nazioni[86] = "THA";
$lista_nazioni[87] = "Timor-Leste";
$cod_nazioni[87] = "TL";
$cod2_nazioni[87] = "TLS";
$lista_nazioni[88] = "Turkmenistán";
$cod_nazioni[88] = "TM";
$cod2_nazioni[88] = "TKM";
$lista_nazioni[89] = "Uzbekistán";
$cod_nazioni[89] = "UZ";
$cod2_nazioni[89] = "UZB";
$lista_nazioni[90] = "Viet Nam";
$cod_nazioni[90] = "VN";
$cod2_nazioni[90] = "VNM";
$lista_nazioni[91] = "Yemen";
$cod_nazioni[91] = "YE";
$cod2_nazioni[91] = "YEM";
$lista_nazioni[92] = "Argelia";
$cod_nazioni[92] = "DZ";
$cod2_nazioni[92] = "DZA";
$lista_nazioni[93] = "Angola";
$cod_nazioni[93] = "AO";
$cod2_nazioni[93] = "AGO";
$lista_nazioni[94] = "Benin";
$cod_nazioni[94] = "BJ";
$cod2_nazioni[94] = "BEN";
$lista_nazioni[95] = "Botswana";
$cod_nazioni[95] = "BW";
$cod2_nazioni[95] = "BWA";
$lista_nazioni[96] = "Burkina Faso";
$cod_nazioni[96] = "BF";
$cod2_nazioni[96] = "BFA";
$lista_nazioni[97] = "Burundi";
$cod_nazioni[97] = "BI";
$cod2_nazioni[97] = "BDI";
$lista_nazioni[98] = "Camerún";
$cod_nazioni[98] = "CM";
$cod2_nazioni[98] = "CMR";
$lista_nazioni[99] = "Cabo Verde";
$cod_nazioni[99] = "CV";
$cod2_nazioni[99] = "CPV";
$lista_nazioni[100] = "República Centroafricana";
$cod_nazioni[100] = "CF";
$cod2_nazioni[100] = "CAF";
$lista_nazioni[101] = "Chad";
$cod_nazioni[101] = "TD";
$cod2_nazioni[101] = "TCD";
$lista_nazioni[102] = "Comoras";
$cod_nazioni[102] = "KM";
$cod2_nazioni[102] = "COM";
$lista_nazioni[103] = "Congo";
$cod_nazioni[103] = "CG";
$cod2_nazioni[103] = "COG";
$lista_nazioni[104] = "Repúb. Dem. Del Congo";
$cod_nazioni[104] = "CD";
$cod2_nazioni[104] = "COD";
$lista_nazioni[105] = "Côte D'Ivoire";
$cod_nazioni[105] = "CI";
$cod2_nazioni[105] = "CIV";
$lista_nazioni[106] = "Egipto";
$cod_nazioni[106] = "EG";
$cod2_nazioni[106] = "EGY";
$lista_nazioni[107] = "Eritrea";
$cod_nazioni[107] = "ER";
$cod2_nazioni[107] = "ERI";
$lista_nazioni[108] = "Etiopía";
$cod_nazioni[108] = "ET";
$cod2_nazioni[108] = "ETH";
$lista_nazioni[109] = "Gabón";
$cod_nazioni[109] = "GA";
$cod2_nazioni[109] = "GAB";
$lista_nazioni[110] = "Gambia";
$cod_nazioni[110] = "GM";
$cod2_nazioni[110] = "GMB";
$lista_nazioni[111] = "Ghana";
$cod_nazioni[111] = "GH";
$cod2_nazioni[111] = "GHA";
$lista_nazioni[112] = "Djibouti";
$cod_nazioni[112] = "DJ";
$cod2_nazioni[112] = "DJI";
$lista_nazioni[113] = "Guinea";
$cod_nazioni[113] = "GN";
$cod2_nazioni[113] = "GIN";
$lista_nazioni[114] = "Guinea-Bissau";
$cod_nazioni[114] = "GW";
$cod2_nazioni[114] = "GNB";
$lista_nazioni[115] = "Guinea Ecuatorial";
$cod_nazioni[115] = "GQ";
$cod2_nazioni[115] = "GNQ";
$lista_nazioni[116] = "Kenya";
$cod_nazioni[116] = "KE";
$cod2_nazioni[116] = "KEN";
$lista_nazioni[117] = "Lesotho";
$cod_nazioni[117] = "LS";
$cod2_nazioni[117] = "LSO";
$lista_nazioni[118] = "Liberia";
$cod_nazioni[118] = "LR";
$cod2_nazioni[118] = "LBR";
$lista_nazioni[119] = "Libia";
$cod_nazioni[119] = "LY";
$cod2_nazioni[119] = "LBY";
$lista_nazioni[120] = "Madagascar";
$cod_nazioni[120] = "MG";
$cod2_nazioni[120] = "MDG";
$lista_nazioni[121] = "Malawi";
$cod_nazioni[121] = "MW";
$cod2_nazioni[121] = "MWI";
$lista_nazioni[122] = "Malí";
$cod_nazioni[122] = "ML";
$cod2_nazioni[122] = "MLI";
$lista_nazioni[123] = "Marruecos";
$cod_nazioni[123] = "MA";
$cod2_nazioni[123] = "MAR";
$lista_nazioni[124] = "Mauritania";
$cod_nazioni[124] = "MR";
$cod2_nazioni[124] = "MRT";
$lista_nazioni[125] = "Mauricio";
$cod_nazioni[125] = "MU";
$cod2_nazioni[125] = "MUS";
$lista_nazioni[126] = "Mozambique";
$cod_nazioni[126] = "MZ";
$cod2_nazioni[126] = "MOZ";
$lista_nazioni[127] = "Namibia";
$cod_nazioni[127] = "NA";
$cod2_nazioni[127] = "NAM";
$lista_nazioni[128] = "Níger";
$cod_nazioni[128] = "NE";
$cod2_nazioni[128] = "NER";
$lista_nazioni[129] = "Nigeria";
$cod_nazioni[129] = "NG";
$cod2_nazioni[129] = "NGA";
$lista_nazioni[130] = "Rwanda";
$cod_nazioni[130] = "RW";
$cod2_nazioni[130] = "RWA";
$lista_nazioni[131] = "Santo Tomé Y Príncipe";
$cod_nazioni[131] = "ST";
$cod2_nazioni[131] = "STP";
$lista_nazioni[132] = "Senegal";
$cod_nazioni[132] = "SN";
$cod2_nazioni[132] = "SEN";
$lista_nazioni[133] = "Seychelles";
$cod_nazioni[133] = "SC";
$cod2_nazioni[133] = "SYC";
$lista_nazioni[134] = "Sierra Leona";
$cod_nazioni[134] = "SL";
$cod2_nazioni[134] = "SLE";
$lista_nazioni[135] = "Somalia";
$cod_nazioni[135] = "SO";
$cod2_nazioni[135] = "SOM";
$lista_nazioni[136] = "Sudáfrica";
$cod_nazioni[136] = "ZA";
$cod2_nazioni[136] = "ZAF";
$lista_nazioni[137] = "Sudán";
$cod_nazioni[137] = "SD";
$cod2_nazioni[137] = "SDN";
$lista_nazioni[138] = "Swazilandia";
$cod_nazioni[138] = "SZ";
$cod2_nazioni[138] = "SWZ";
$lista_nazioni[139] = "Tanzanía";
$cod_nazioni[139] = "TZ";
$cod2_nazioni[139] = "TZA";
$lista_nazioni[140] = "Togo";
$cod_nazioni[140] = "TG";
$cod2_nazioni[140] = "TGO";
$lista_nazioni[141] = "Túnez";
$cod_nazioni[141] = "TN";
$cod2_nazioni[141] = "TUN";
$lista_nazioni[142] = "Uganda";
$cod_nazioni[142] = "UG";
$cod2_nazioni[142] = "UGA";
$lista_nazioni[143] = "Zambia";
$cod_nazioni[143] = "ZM";
$cod2_nazioni[143] = "ZMB";
$lista_nazioni[144] = "Zimbabwe";
$cod_nazioni[144] = "ZW";
$cod2_nazioni[144] = "ZWE";
$lista_nazioni[145] = "Antigua Y Barbuda";
$cod_nazioni[145] = "AG";
$cod2_nazioni[145] = "ATG";
$lista_nazioni[146] = "Argentina";
$cod_nazioni[146] = "AR";
$cod2_nazioni[146] = "ARG";
$lista_nazioni[147] = "Bahamas";
$cod_nazioni[147] = "BS";
$cod2_nazioni[147] = "BHS";
$lista_nazioni[148] = "Barbados";
$cod_nazioni[148] = "BB";
$cod2_nazioni[148] = "BRB";
$lista_nazioni[149] = "Belice";
$cod_nazioni[149] = "BZ";
$cod2_nazioni[149] = "BLZ";
$lista_nazioni[150] = "Bolivia";
$cod_nazioni[150] = "BO";
$cod2_nazioni[150] = "BOL";
$lista_nazioni[151] = "Brasil";
$cod_nazioni[151] = "BR";
$cod2_nazioni[151] = "BRA";
$lista_nazioni[152] = "Canadá";
$cod_nazioni[152] = "CA";
$cod2_nazioni[152] = "CAN";
$lista_nazioni[153] = "Chile";
$cod_nazioni[153] = "CL";
$cod2_nazioni[153] = "CHL";
$lista_nazioni[154] = "Colombia";
$cod_nazioni[154] = "CO";
$cod2_nazioni[154] = "COL";
$lista_nazioni[155] = "Costa Rica";
$cod_nazioni[155] = "CR";
$cod2_nazioni[155] = "CRI";
$lista_nazioni[156] = "Cuba";
$cod_nazioni[156] = "CU";
$cod2_nazioni[156] = "CUB";
$lista_nazioni[157] = "Dominica";
$cod_nazioni[157] = "DM";
$cod2_nazioni[157] = "DMA";
$lista_nazioni[158] = "República Dominicana";
$cod_nazioni[158] = "DO";
$cod2_nazioni[158] = "DOM";
$lista_nazioni[159] = "Ecuador";
$cod_nazioni[159] = "EC";
$cod2_nazioni[159] = "ECU";
$lista_nazioni[160] = "El Salvador";
$cod_nazioni[160] = "SV";
$cod2_nazioni[160] = "SLV";
$lista_nazioni[161] = "Jamaica";
$cod_nazioni[161] = "JM";
$cod2_nazioni[161] = "JAM";
$lista_nazioni[162] = "Granada";
$cod_nazioni[162] = "GD";
$cod2_nazioni[162] = "GRD";
$lista_nazioni[163] = "Guatemala";
$cod_nazioni[163] = "GT";
$cod2_nazioni[163] = "GTM";
$lista_nazioni[164] = "Guyana";
$cod_nazioni[164] = "GY";
$cod2_nazioni[164] = "GUY";
$lista_nazioni[165] = "Haití";
$cod_nazioni[165] = "HT";
$cod2_nazioni[165] = "HTI";
$lista_nazioni[166] = "Honduras";
$cod_nazioni[166] = "HN";
$cod2_nazioni[166] = "HND";
$lista_nazioni[167] = "México";
$cod_nazioni[167] = "MX";
$cod2_nazioni[167] = "MEX";
$lista_nazioni[168] = "Nicaragua";
$cod_nazioni[168] = "NI";
$cod2_nazioni[168] = "NIC";
$lista_nazioni[169] = "Panamá";
$cod_nazioni[169] = "PA";
$cod2_nazioni[169] = "PAN";
$lista_nazioni[170] = "Paraguay";
$cod_nazioni[170] = "PY";
$cod2_nazioni[170] = "PRY";
$lista_nazioni[171] = "Perú";
$cod_nazioni[171] = "PE";
$cod2_nazioni[171] = "PER";
$lista_nazioni[172] = "Saint Kitts Y Nevis";
$cod_nazioni[172] = "KN";
$cod2_nazioni[172] = "KNA";
$lista_nazioni[173] = "Santa Lucía";
$cod_nazioni[173] = "LC";
$cod2_nazioni[173] = "LCA";
$lista_nazioni[174] = "San Vicente Y Granadinas";
$cod_nazioni[174] = "VC";
$cod2_nazioni[174] = "VCT";
$lista_nazioni[175] = "Estados Unidos De América";
$cod_nazioni[175] = "US";
$cod2_nazioni[175] = "USA";
$lista_nazioni[176] = "Suriname";
$cod_nazioni[176] = "SR";
$cod2_nazioni[176] = "SUR";
$lista_nazioni[177] = "Trinidad Y Tabago";
$cod_nazioni[177] = "TT";
$cod2_nazioni[177] = "TTO";
$lista_nazioni[178] = "Uruguay";
$cod_nazioni[178] = "UY";
$cod2_nazioni[178] = "URY";
$lista_nazioni[179] = "Venezuela";
$cod_nazioni[179] = "VE";
$cod2_nazioni[179] = "VEN";
$lista_nazioni[180] = "Australia";
$cod_nazioni[180] = "AU";
$cod2_nazioni[180] = "AUS";
$lista_nazioni[181] = "Fiji";
$cod_nazioni[181] = "FJ";
$cod2_nazioni[181] = "FJI";
$lista_nazioni[182] = "Kiribati";
$cod_nazioni[182] = "KI";
$cod2_nazioni[182] = "KIR";
$lista_nazioni[183] = "Islas Marshall";
$cod_nazioni[183] = "MH";
$cod2_nazioni[183] = "MHL";
$lista_nazioni[184] = "Micronesia";
$cod_nazioni[184] = "FM";
$cod2_nazioni[184] = "FSM";
$lista_nazioni[185] = "Nauru";
$cod_nazioni[185] = "NR";
$cod2_nazioni[185] = "NRU";
$lista_nazioni[186] = "Nueva Zelandia";
$cod_nazioni[186] = "NZ";
$cod2_nazioni[186] = "NZL";
$lista_nazioni[187] = "Palau";
$cod_nazioni[187] = "PW";
$cod2_nazioni[187] = "PLW";
$lista_nazioni[188] = "Papua Nueva Guinea";
$cod_nazioni[188] = "PG";
$cod2_nazioni[188] = "PNG";
$lista_nazioni[189] = "Islas Salomón";
$cod_nazioni[189] = "SB";
$cod2_nazioni[189] = "SLB";
$lista_nazioni[190] = "Samoa";
$cod_nazioni[190] = "WS";
$cod2_nazioni[190] = "WSM";
$lista_nazioni[191] = "Tonga";
$cod_nazioni[191] = "TO";
$cod2_nazioni[191] = "TON";
$lista_nazioni[192] = "Tuvalu";
$cod_nazioni[192] = "TV";
$cod2_nazioni[192] = "TUV";
$lista_nazioni[193] = "Vanuatu";
$cod_nazioni[193] = "VU";
$cod2_nazioni[193] = "VUT";
$lista_nazioni[194] = "Italia";
$cod_nazioni[194] = "IT";
$cod2_nazioni[194] = "ITA";
$lista_nazioni[195] = "Kosovo";
$cod_nazioni[195] = "XK";
$cod2_nazioni[195] = "XKX";
$lista_nazioni[196] = "Sudán Del Sur";
$cod_nazioni[196] = "SS";
$cod2_nazioni[196] = "SSD";


?>